@@ -27,13 +27,11 @@ use warnings::register;
 
 # Inheritance -------------------------
 
-use Exporter   5.562 qw( );
-use AutoLoader 5.57  qw( AUTOLOAD );
-our @ISA = qw( AutoLoader Exporter );
-our @EXPORT_OK = qw( $PACKAGE $VERSION );
+our @ISA = qw( AutoLoader );
 
 # Utility -----------------------------
 
+use AutoLoader                   qw( AUTOLOAD );
 use Carp                         qw( carp croak cluck );
 use Class::MethodMaker::OptExt   qw( OPTEXT );
 use Class::MethodMaker::V1Compat qw( V1COMPAT );
@@ -58,14 +56,8 @@ BEGIN {
 
 # -------------------------------------
 
-our $VERSION;
-BEGIN {
-  our $PACKAGE = 'Class-MethodMaker';
-  our $VERSION = '2.03';
-}
-
-use XSLoader qw();
-XSLoader::load 'Class::MethodMaker::Engine', $VERSION;
+our $PACKAGE = 'Class-MethodMaker';
+our $VERSION = '2.05';
 
 # -------------------------------------
 # CLASS CONSTRUCTION
@@ -713,7 +705,9 @@ sub _find_target_class {
   do {
     $target = (caller($i))[0];
     $i++;
-  } while ( $target->isa('Class::MethodMaker::Engine')    and
+  } while ( ( $target->isa('Class::MethodMaker::Engine') 
+              or
+              $target->isa('Class::MethodMaker') )       and
             # This is "supported" for v1 compatibility only.  Direct calling
             # of create_methods is the preferred way of using
             # Class::MethodMaker to build C::MM subclasses
@@ -784,7 +778,7 @@ sub install_methods {
         *{$methname} = $code;
         # Generate a unique stash name for the sub.  Use a preceding space
         # to avoid collisions with anything in the Perl space.
-        set_sub_name($code, $target, $name, " ${target}::${name}");
+        Class::MethodMaker::set_sub_name($code, $target, $name, " ${target}::${name}");
       }
     } else {
       croak "What do you expect me to do with this?: $code\n";
